==> phptoast-8.0.0.tgz: package/test/integration/operators/logical/xorTest.js <==
/*
 * PHP-To-AST - PHP parser
 * Copyright (c) Dan Phillimore (asmblah)
 * http://uniter.github.com/phptoast/
 *
 * Released under the MIT license
 * https://github.com/uniter/phptoast/raw/master/MIT-LICENSE.txt
 */

'use strict';

var _ = require('microdash'),
    expect = require('chai').expect,
    tools = require('../../../tools');

describe('PHP Parser grammar logical Xor "<value> xor <value>" operator integration', function () {
    var parser;

    beforeEach(function () {
        parser = tools.createParser();
    });

    _.each({
        'assigning Xor of variable values to another variable': {
            code: '$result = $value1 xOr $value2;', // Test cae-insensitivity
            expectedAST: {
                name: 'N_PROGRAM',
                statements: [{
                    name: 'N_EXPRESSION_STATEMENT',
                    expression: {
                        name: 'N_EXPRESSION',
                        left: {
                            name: 'N_VARIABLE',
                            variable: 'result'
                        },
                        right: [{
                            operator: '=',
                            operand: {
                                name: 'N_EXPRESSION',
                                left: {
                                    name: 'N_VARIABLE',
                                    variable: 'value1'
                                },
                                right: [{
                                    operator: 'xor',
                                    operand: {
                                        name: 'N_VARIABLE',
                                        variable: 'value2'
                                    }
                                }]
                            }
                        }]
                    }
                }]
            }
        },
        'assigning condition with assignment inside operand to variable': {
            code: '$result = (first_func() xor $pos = second_func());',
            expectedAST: {
                name: 'N_PROGRAM',
                statements: [{
                    name: 'N_EXPRESSION_STATEMENT',
                    expression: {
                        name: 'N_EXPRESSION',
                        left: {
                            name: 'N_VARIABLE',
                            variable: 'result'
                        },
                        right: [{
                            operator: '=',
                            operand: {
                                name: 'N_EXPRESSION',
                                left: {
                                    name: 'N_FUNCTION_CALL',
                                    func: {
                                        name: 'N_STRING',
                                        string: 'first_func'
                                    },
                                    args: []
                                },
                                right: [{
                                    operator: 'xor',
                                    operand: {
                                        name: 'N_EXPRESSION',
                                        left: {
                                            name: 'N_VARIABLE',
                                            variable: 'pos'
                                        },
                                        right: [{
                                            operator: '=',
                                            operand: {
                                                name: 'N_FUNCTION_CALL',
                                                func: {
                                                    name: 'N_STRING',
                                                    string: 'second_func'
                                                },
                                                args: []
                                            }
                                        }]
                                    }
                                }]
                            }
                        }]
                    }
                }]
            }
        }
    }, function (scenario, description) {
        describe(description, function () {
            var code = '<?php ' + scenario.code;

            // Pretty-print the code strings so any non-printable characters are readable
            describe('when the code is ' + JSON.stringify(code) + ' ?>', function () {
                it('should return the expected AST', function () {
                    expect(parser.parse(code)).to.deep.equal(scenario.expectedAST);
                });
            });
        });
    });
});

==> phptoast-9.1.1.tgz: package/test/integration/operators/logical/xorTest.js <==
/*
 * PHP-To-AST - PHP parser
 * Copyright (c) Dan Phillimore (asmblah)
 * http://uniter.github.com/phptoast/
 *
 * Released under the MIT license
 * https://github.com/uniter/phptoast/raw/master/MIT-LICENSE.txt
 */

'use strict';

var _ = require('microdash'),
    expect = require('chai').expect,
    tools = require('../../../tools');

describe('PHP Parser grammar logical Xor "<value> xor <value>" operator integration', function () {
    var parser;

    beforeEach(function () {
        parser = tools.createParser();
    });

    _.each({
        'assigning Xor of variable values to another variable': {
            code: '$result = $value1 xOr $value2;', // Test case-insensitivity.
            expectedAST: {
                name: 'N_PROGRAM',
                statements: [{
                    name: 'N_EXPRESSION_STATEMENT',
                    expression: {
                        name: 'N_EXPRESSION',
                        left: {
                            name: 'N_VARIABLE',
                            variable: 'result'
                        },
                        right: [{
                            operator: '=',
                            operand: {
                                name: 'N_EXPRESSION',
                                left: {
                                    name: 'N_VARIABLE',
                                    variable: 'value1'
                                },
                                right: [{
                                    operator: 'xor',
                                    operand: {
                                        name: 'N_VARIABLE',
                                        variable: 'value2'
                                    }
                                }]
                            }
                        }]
                    }
                }]
            }
        },
        'assigning condition with assignment inside operand to variable': {
            code: '$result = (first_func() xor $pos = second_func());',
            expectedAST: {
                name: 'N_PROGRAM',
                statements: [{
                    name: 'N_EXPRESSION_STATEMENT',
                    expression: {
                        name: 'N_EXPRESSION',
                        left: {
                            name: 'N_VARIABLE',
                            variable: 'result'
                        },
                        right: [{
                            operator: '=',
                            operand: {
                                name: 'N_EXPRESSION',
                                left: {
                                    name: 'N_FUNCTION_CALL',
                                    func: {
                                        name: 'N_STRING',
                                        string: 'first_func'
                                    },
                                    args: []
                                },
                                right: [{
                                    operator: 'xor',
                                    operand: {
                                        name: 'N_EXPRESSION',
                                        left: {
                                            name: 'N_VARIABLE',
                                            variable: 'pos'
                                        },
                                        right: [{
                                            operator: '=',
                                            operand: {
                                                name: 'N_FUNCTION_CALL',
                                                func: {
                                                    name: 'N_STRING',
                                                    string: 'second_func'
                                                },
                                                args: []
                                            }
                                        }]
                                    }
                                }]
                            }
                        }]
                    }
                }]
            }
        }
    }, function (scenario, description) {
        describe(description, function () {
            var code = '<?php ' + scenario.code;

            // Pretty-print the code strings so any non-printable characters are readable
            describe('when the code is ' + JSON.stringify(code) + ' ?>', function () {
                it('should return the expected AST', function () {
                    expect(parser.parse(code)).to.deep.equal(scenario.expectedAST);
                });
            });
        });
    });
});
